@@ -9,6 +9,7 @@ import requests
 
 URL = 'http://loadingproductions.com'
 TEST_URL = 'http://127.0.0.1:5000'
+TEST_CLOUD_URL = 'http://3.137.160.113:5000'
 
 
 def config():
@@ -88,14 +89,16 @@ def run(url: str, interval=10, wait=5):
 def main():
     print("[1] Run driver with official API")
     print("[2] Test driver with local API")
-    print("[3] presentation")
+    print("[3] Test driver with local API")
+    print("[4] presentation")
     response = input("What would you like to run? ")
-    choices = ['1', '2', '3']
+    choices = ['1', '2', '3', '4']
     while response not in choices:
         print(f"ERROR: your response should be a choice of: {choices}")
         print("[1] Run driver with official API")
         print("[2] Test driver with local API")
-        print("[3] presentation")
+        print("[3] Test driver with local API")
+        print("[4] presentation")
         response = input("What would you like to run? ")
 
     if response == '1':
@@ -109,6 +112,11 @@ def main():
         assert res.json()['connection'] == "successful"
         run(TEST_URL, interval=5, wait=5)
     elif response == '3':
+        res = requests.get(TEST_CLOUD_URL + '/ping')
+        assert res.status_code == 200, f"Url returned status code: {res.status_code}"
+        assert res.json()['connection'] == "successful"
+        run(TEST_CLOUD_URL, interval=5, wait=5)
+    elif response == '4':
         presentation()
 
 
